@@ -259,7 +259,7 @@ class Consumer(ConsumerMixinFix):
         :param kwargs: 父类参数默认值
         :return:
         """
-        assert self.queues is not None
+        assert self.queue is not None
         assert self.callback_handle is not None
         signal.signal(signal.SIGTERM, self.stop)
         signal.signal(signal.SIGINT, self.stop)
